@@ -1,9 +1,10 @@
 #ifndef FCGID_CONF_H
 #define FCGID_CONF_H
 #include "apr_user.h"
+#include "fcgid_global.h"
 
 typedef struct {
-	char wrapper_path[APR_PATH_MAX];
+	char wrapper_path[_POSIX_PATH_MAX];
 	apr_ino_t inode;
 	apr_dev_t deviceid;
 	apr_size_t share_group_id;
@@ -12,7 +13,6 @@ typedef struct {
 typedef struct {
 	int idle_timeout;
 	int idle_scan_interval;
-	int busy_timeout;
 	int busy_scan_interval;
 	int proc_lifetime;
 	int error_scan_interval;
@@ -23,14 +23,26 @@ typedef struct {
 	int termination_score;
 	int max_process_count;
 	int default_max_class_process_count;
-	int ipc_connect_timeout;
-	int ipc_comm_timeout;
 	int output_buffersize;
 	apr_table_t *default_init_env;
-	apr_hash_t *wrapper_info_hash;
-} fcgid_conf;
 
-void *create_fcgid_config(apr_pool_t * p, server_rec * s);
+	int ipc_connect_timeout;
+	int ipc_connect_timeout_overwrite;
+	int ipc_comm_timeout;
+	int ipc_comm_timeout_overwrite;
+	int busy_timeout;
+	int busy_timeout_overwrite;
+} fcgid_server_conf;
+
+typedef struct {
+	apr_hash_t *wrapper_info_hash;
+} fcgid_dir_conf;
+
+void *create_fcgid_server_config(apr_pool_t * p, server_rec * s);
+void *merge_fcgid_server_config(apr_pool_t * p, void *basev,
+								void *overridesv);
+
+void *create_fcgid_dir_config(apr_pool_t * p, char *dummy);
 
 const char *set_idle_timeout(cmd_parms * cmd, void *dummy,
 							 const char *arg);
@@ -96,12 +108,10 @@ int get_output_buffersize(server_rec * s);
 
 const char *add_default_env_vars(cmd_parms * cmd, void *sconf,
 								 const char *name, const char *value);
-apr_table_t *get_default_env_vars(server_rec * s);
+apr_table_t *get_default_env_vars(request_rec * r);
 
 const char *set_wrapper_config(cmd_parms * cmd, void *dummy,
 							   const char *wrapper, const char *extension);
-const char *set_wrappergrp_config(cmd_parms * cmd, void *dummy,
-								  const char *thearg);
-fcgid_wrapper_conf *get_wrapper_info(const char *cgipath, server_rec * s);
+fcgid_wrapper_conf *get_wrapper_info(const char *cgipath, request_rec * r);
 
 #endif
